==> slds-button-0.1.0.tgz: package/__tests__/button.js <==
/* eslint-env jest */
import { SldsButton } from '../button';
import * as utils from '../../../../../.jest/utils';
// Register custom element for jest wrapper
customElements.define('slds-button', SldsButton);

describe('slds-button', () => {
  afterEach(() => {
    // The jsdom instance is shared across test cases in a single file so reset the DOM
    while (document.body.firstChild) {
      document.body.removeChild(document.body.firstChild);
    }
  });
  it('named part exists on button element', async () => {
    const element = utils.renderIntoBody(`<slds-button>Test</slds-button>`);
    const button = element.shadowRoot.querySelector('button');
    expect(button).toHaveAttribute('part', 'button');
  });
  it('size attribute exists on slds element', async () => {
    const element = utils.renderIntoBody(`<slds-button size="stretch">Test</slds-button>`);
    expect(element).toHaveAttribute('size', 'stretch');
  });
  it('variant attribute exists on slds element', async () => {
    const element = utils.renderIntoBody(`<slds-button variant="brand">Test</slds-button>`);
    expect(element).toHaveAttribute('variant', 'brand');
  });
  it('disabled attribute delegates to button element', async () => {
    const element = utils.renderIntoBody(`<slds-button disabled>Test</slds-button>`);
    const button = element.shadowRoot.querySelector('button');
    expect(element).not.toHaveAttribute('disabled', 'true');
    expect(button).toHaveAttribute('disabled', 'true');
  });
  it('default attributes exists on slds element', async () => {
    const element = utils.renderIntoBody(`<slds-button>Test</slds-button>`);
    const button = element.shadowRoot.querySelector('button');
    expect(button).not.toHaveAttribute('disabled', 'true');
    expect(element).toHaveAttribute('variant', 'neutral');
  });
});

==> slds-button-0.4.0.tgz: package/__tests__/button.js <==
/* eslint-env jest */
import { SldsButton } from '../button';
import * as utils from '../../../../../.jest/utils';
// Register custom element for jest wrapper
customElements.define('slds-button', SldsButton);

describe('slds-button', () => {
  afterEach(() => {
    // The jsdom instance is shared across test cases in a single file so reset the DOM
    while (document.body.firstChild) {
      document.body.removeChild(document.body.firstChild);
    }
  });
  it('named part exists on button element', async () => {
    const element = utils.renderIntoBody(`<slds-button>Test</slds-button>`);
    const button = element.shadowRoot.querySelector('button');
    expect(button).toHaveAttribute('part', 'button');
  });
  it('size attribute exists on slds element', async () => {
    const element = utils.renderIntoBody(`<slds-button size="stretch">Test</slds-button>`);
    expect(element).toHaveAttribute('size', 'stretch');
  });
  it('variant attribute exists on slds element', async () => {
    const element = utils.renderIntoBody(`<slds-button variant="brand">Test</slds-button>`);
    expect(element).toHaveAttribute('variant', 'brand');
  });
  it('disabled attribute delegates to button element', async () => {
    const element = utils.renderIntoBody(`<slds-button disabled>Test</slds-button>`);
    const button = element.shadowRoot.querySelector('button');
    expect(element).not.toHaveAttribute('disabled', '');
    expect(button).toHaveAttribute('disabled', '');
  });
  it('default attributes exists on slds element', async () => {
    const element = utils.renderIntoBody(`<slds-button>Test</slds-button>`);
    const button = element.shadowRoot.querySelector('button');
    expect(button).not.toHaveAttribute('disabled', '');
    expect(element).toHaveAttribute('variant', 'neutral');
  });
});
